==> apigateway-0.28.0-sources.jar: software/amazon/awscdk/services/apigateway/CfnIntegrationV2.java <==
package software.amazon.awscdk.services.apigateway;

/**
 * @cloudformationResource AWS::ApiGatewayV2::Integration
 * A CloudFormation `AWS::ApiGatewayV2::Integration`
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigatewayv2-integration.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.8.2 (build e9eb3c9)", date = "2019-04-04T15:08:10.874Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.apigateway.$Module.class, fqn = "@aws-cdk/aws-apigateway.CfnIntegrationV2")
public class CfnIntegrationV2 extends software.amazon.awscdk.CfnResource {
    protected CfnIntegrationV2(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.apigateway.CfnIntegrationV2.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Create a new `AWS::ApiGatewayV2::Integration`.
     * @param scope - scope in which this resource is defined
     * @param id - scoped id of the resource
     * @param props - resource properties
     */
    public CfnIntegrationV2(final software.amazon.awscdk.Construct scope, final java.lang.String id, final software.amazon.awscdk.services.apigateway.CfnIntegrationV2Props props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(scope, "scope is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(id, "id is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(props, "props is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required")).toArray());
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    public java.lang.String getIntegrationId() {
        return this.jsiiGet("integrationId", java.lang.String.class);
    }

    public software.amazon.awscdk.services.apigateway.CfnIntegrationV2Props getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.apigateway.CfnIntegrationV2Props.class);
    }
}

==> apigateway-0.29.0-sources.jar: software/amazon/awscdk/services/apigateway/CfnIntegrationV2.java <==
package software.amazon.awscdk.services.apigateway;

/**
 * A CloudFormation `AWS::ApiGatewayV2::Integration`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigatewayv2-integration.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.10.3 (build 6bbf743)", date = "2019-04-24T21:05:16.123Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.apigateway.$Module.class, fqn = "@aws-cdk/aws-apigateway.CfnIntegrationV2")
public class CfnIntegrationV2 extends software.amazon.awscdk.CfnResource {
    protected CfnIntegrationV2(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.apigateway.CfnIntegrationV2.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Create a new `AWS::ApiGatewayV2::Integration`.
     * 
     * @param scope - scope in which this resource is defined.
     * @param id - scoped id of the resource.
     * @param props - resource properties.
     */
    public CfnIntegrationV2(final software.amazon.awscdk.Construct scope, final java.lang.String id, final software.amazon.awscdk.services.apigateway.CfnIntegrationV2Props props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(@javax.annotation.Nullable final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, new Object[] { properties });
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    public java.lang.String getIntegrationId() {
        return this.jsiiGet("integrationId", java.lang.String.class);
    }

    public software.amazon.awscdk.services.apigateway.CfnIntegrationV2Props getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.apigateway.CfnIntegrationV2Props.class);
    }
}
